so_pysm_models Documentation — so_pysm_models v0.4.dev231

so_pysm_models:docs

- Index
- Modules

### Navigation

- next »
- so_pysm_models v0.4.dev231 »

# so_pysm_models Documentation

This is the documentation for so_pysm_models.

Contents:

- Getting started
  - Installation
  - Development installation
  - Example Usage
- Summary of Models
  - GaussianSynchrotron
  - GaussianDust
  - COLines
  - PrecomputedAlms
  - InterpolatingComponent
  - WebSky
- High resolution templates
  - Details about individual models

## Reference/API

### so_pysm_models Package

#### Functions

`get_so_models`(key, nside[, map_dist]) |
`test`(\*\*kwargs) | Run the tests for the package.

#### Classes

`COLines`(target_nside, output_units[, …]) | Class defining attributes for CO line emission.
`GaussianDust`(nside[, has_polarization, …]) | Gaussian dust model
`GaussianSynchrotron`(nside[, …]) | Gaussian synchrotron model
`PrecomputedAlms`(filename[, input_units, …]) | Generic component based on Precomputed Alms
`UnsupportedPythonError` |
`WebSkyCIB`([websky_version, input_units, …]) | PySM component interpolating between precomputed maps
`WebSkyCMB`(websky_version, nside[, …]) |
`WebSkySZ`([version, sz_type, nside, …]) |

#### Class Inheritance Diagram